#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2024-06-23
# File  : cisco_meraki_org_appliance_performance.py (WATO)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
)


def _parameter_valuespec_cisco_meraki_org_appliance_performance():
    return Dictionary(
        title=_('Cisco Meraki Appliance Utilization'),
        optional_keys=True,
        elements=[
            ('levels_upper',
             Tuple(
                 title=_('Upper Levels'),
                 elements=[
                     Integer(
                         title=_("Warning at"),
                         unit='%',
                         default_value=60,
                         minvalue=0,
                         maxvalue=101,
                     ),
                     Integer(
                         title=_("Critical at"),
                         unit='%',
                         default_value=80,
                         minvalue=0,
                         maxvalue=101,
                     ),
                 ],
                 help=_(
                     'The device utilization data reported to the Meraki'
                     ' dashboard is based on a load average measured over a'
                     ' period of one minute. The load value is returned in'
                     ' numeric values ranging from 1 through 100. A lower'
                     ' value indicates a lower load, and a higher value'
                     ' indicates a more intense workload. Currently, the'
                     ' device utilization value is calculated based upon the'
                     ' CPU utilization of the MX as well as its traffic load.'
                     ' If an MX device is consistently over 50% utilization'
                     ' during normal operation, upgrading to a higher'
                     ' throughput model or reducing the per-device load'
                     ' through horizontal scaling should be considered. For'
                     ' more information see:'
                     ' https://documentation.meraki.com-MX-Monitoring?and?'
                     'Reporting-Device?Utiliyation'),
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        title=lambda: _('Cisco Meraki Appliance Utilization'),
        check_group_name='cisco_meraki_org_appliance_performance',
        group=RulespecGroupCheckParametersNetworking,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_org_appliance_performance,
        match_type='dict',
    )
)
