#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-11-05
# File  : cisco_meraki_org_appliance_uplinks.py (WATO)

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    RulespecGroupCheckParametersNetworking,
    rulespec_registry,
)
from cmk.gui.valuespec import (
    Dictionary,
    FixedValue,
    MonitoringState,
    TextInput,
)


def _parameter_valuespec_cisco_meraki_org_appliance_uplinks():
    return Dictionary(
        title=_('Cisco Meraki Appliance Uplinks'),
        optional_keys=True,
        elements=[
            ('status_map',
             Dictionary(
                 title=_('Map uplink status to monitoring state'),
                 elements=[
                     ("active",
                      MonitoringState(
                          title=_('Monitoring state for uplink state "active"'),
                          default_value=0,
                      )),
                     ("ready",
                      MonitoringState(
                          title=_('Monitoring state for uplink state "ready"'),
                          default_value=1,
                      )),
                     ("not connected",
                      MonitoringState(
                          title=_('Monitoring state for uplink state "not connected"'),
                          default_value=2,
                      )),
                     ("failed",
                      MonitoringState(
                          title=_('Monitoring state for uplink state "failed"'),
                          default_value=2,
                      )),
                 ]
             )),
            # not needed, if we don't want usage -> disable in agent
            # ('show_traffic',
            #  FixedValue(
            #      True,
            #      title=_('Show bandwidth (use only with cache disabled)'),
            #      totext='Bandwidth monitoring enabled',
            #      help=_(
            #          'Use only with cache disabled in the Meraki special agent settings. '
            #          'The throughput be based on the usage for the last 60 seconds.'
            #      )
            #  ))
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        title=lambda: _('Cisco Meraki Appliance uplinks'),
        check_group_name='cisco_meraki_org_appliance_uplinks',
        group=RulespecGroupCheckParametersNetworking,
        parameter_valuespec=_parameter_valuespec_cisco_meraki_org_appliance_uplinks,
        match_type='dict',
        item_spec=lambda: TextInput(
            title=_('The Uplink name'),
        ),
    )
)
